@@ -1,4 +1,4 @@
-﻿# set MKS Korn shell environment variables for MS Visual Studio
+# set MKS Korn shell environment variables for MS Visual Studio
 # 2015/2019/2022 Community
 
 # Revision history
@@ -74,7 +74,7 @@ Options:
   -V<vsversion>  Use Visual Studio <vsversion> (default: 2022)"
 
 # default version; change to suit
-vsversion=2022
+vsversion=2026
 vcverbose=
 
 DUALCASE=1	# MKS Toolkit option to distinguish upper and lower case
@@ -112,6 +112,11 @@ fi
 if [[ -z "$setvcerrors" ]]
 then
     case $vsversion in
+    2026)
+	vsinstalldir="C:\Program Files\Microsoft Visual Studio\18\Community"
+	vcbatdir="$vsinstalldir\VC\Auxiliary\Build"
+	vscommontools=VS180COMNTOOLS
+	;;
     2022)
 	vsinstalldir="C:\Program Files\Microsoft Visual Studio\2022\Community"
 	vcbatdir="$vsinstalldir\VC\Auxiliary\Build"
@@ -160,7 +165,7 @@ then
     vcarches64='x64|amd64|64|64bit|64-bit'
     
     case $vsversion in
-    2019|2022)
+    2019|2022|2026)
 	case $vcarch in
 	x86|x64_x86|amd64_x86|32|32bit|32-bit)
 	    vcbatfile="$vcbatdir\vcvars32.bat"
