@@ -50,13 +50,9 @@
    char *malloc(),  *realloc(),  *getenv();
 #endif
 
-#ifndef strchr
-#  ifdef NO_STRCHR
-#    define strchr(a,b) index((a),(b))
-#  else
-     char *strchr();
-#  endif
-#endif /* !strchr */
+#ifdef NO_STRCHR
+#  define strchr(a,b) index((a),(b))
+#endif
 
 #define E_NORMAL 0
 #define E_PARSE 1
@@ -87,6 +83,11 @@
 #define E_NOTAFUNC 26
 #define E_OVERFLOW 27
 #define E_UNDERFLOW 28
+#define E_TOOMANYARGS 29
+#define E_TOOFEWARGS 30
+#define E_ARGSNOFUNC 31
+#define E_BADCOMPOPERATOR 32
+#define E_BADCOMP 33
 
 extern char *errormsg[];
 
@@ -110,12 +111,25 @@ struct unittype {
 };
 
 
+#define COMP_LT 1
+#define COMP_GT 2
+#define COMP_EQ 3
+#define COMP_GTE 4
+#define COMP_LTE 5
+
+#define MAX_FUNC_PARAMS 20
+
+struct interval {
+  double min, max;
+  int min_open, max_open;
+};  
+
 struct functype {
-  char *param;
+  int param_count;
+  char **param;
   char *def;
-  char *dimen;
-  double *domain_min, *domain_max;
-  int domain_min_open, domain_max_open;
+  char **dimen;
+  struct interval *domain;
 };
 
 struct pair {
@@ -141,8 +155,9 @@ struct parseflag {
 };
 extern struct parseflag parserflags;
 
-extern struct unittype *parameter_value;
-extern char *function_parameter;
+extern struct unittype **parameter_value;
+extern char **function_parameter;
+extern int function_parameter_count;
 
 extern int lastunitset;
 extern struct unittype lastunit;
@@ -157,13 +172,14 @@ void invertunit(struct unittype *theunit);
 int multunit(struct unittype *left, struct unittype *right);
 int expunit(struct unittype *theunit, int  power);
 int addunit(struct unittype *unita, struct unittype *unitb);
+int gtlt_unit(int comp,struct unittype *unita, struct unittype *unitb);
 int rootunit(struct unittype *inunit,int n);
 int unitpower(struct unittype *base, struct unittype *exponent);
 char *dupstr(const char *str, const char *msg);
 char *dupnstr(const char *string, size_t length, const char *msg);
 int unit2num(struct unittype *input);
 struct func *fnlookup(const char *str);
-int evalfunc(struct unittype *theunit, struct func *infunc, int inverse, 
+int evalfunc(int param_count, struct unittype **theunitlist, struct func *infunc, int inverse, 
              int allerror);
 int parseunit(struct unittype *output, const char *input, char **errstr,
               int *errloc);
